@@ -9,7 +9,7 @@ use warnings;
 
 use Scalar::Util;
 use Digest::MD5;
-our $VERSION = '0.16';
+our $VERSION = '0.17';
 
 our @EXPORT = qw[ wrap_hash ];
 
@@ -242,7 +242,7 @@ sub _build_class {
         $dict{set} = <<'END';
 if ( @_ ) {
   require Carp;
-  Carp::croak( q[Modification of a read-only value attempted]) }
+  Carp::croak( q[Modification of a read-only value attempted])
 }
 END
     }
@@ -595,7 +595,7 @@ Hash::Wrap - create on-the-fly objects from hashes
 
 =head1 VERSION
 
-version 0.16
+version 0.17
 
 =head1 SYNOPSIS
 
